import { Component, OnInit } from "@angular/core";
import { remote } from "electron";
import { Infractor } from "../citation-wizard/model/infractor";
import { Citation } from "../citation-wizard/model/citation";
import { Vehicle } from "./model/vehicle";
import { AdditionalComments } from "./model/additional-comments";
import { Infraction } from "./model/infraction";
import {VehicleOwner} from "./model/vehicle-owner";
@Component({
  moduleId: module.id,
  selector: "wizard",
  templateUrl: "templates/citation-wizard.component.html"
})
export class CitationWizardComponent implements OnInit {
  
  //This citation object is used by all child components
  citation: Citation;

  rootDir :string = __dirname;

  argumentsReceived = [];

  constructor() {}

  ngOnInit(): void {
    console.log("Wizard initialized", remote);

    //retrieve the command console arguments 
    this.argumentsReceived = remote.process.argv;

    console.log(this.argumentsReceived);

    //get from the arguments the data related to the infractor
    let infractor: Infractor = this.getInfractorFormArguments(this.argumentsReceived);

    // create a new citation object
    this.initializeACitation(infractor);
  }

  onStepChange(event: any){
    console.log(event);
  }

  onComplete(event: any){
    console.log(event);
    return true;
  }

  getInfractorFormArguments(consoleArguments: any[]): Infractor {
    const infractorJSON = consoleArguments[consoleArguments.length - 1];
    let infractor: Infractor;
    try {
      //const dataTest =  '{ "name": "eduardo", "lastName": "luttinger" }';
      infractor = <Infractor>JSON.parse(infractorJSON);
    } catch (error) {
      infractor = <Infractor>{};
      console.log(error);
    }

    console.log('Infractor: ',infractor);
    return infractor;
  }


  initializeACitation(infractor: Infractor){
    this.citation = <Citation> {};
    this.citation.citationNumber = Math.random().toString().substr(11);
    localStorage.setItem("citationNumber", this.citation.citationNumber);
    this.citation.infractor = infractor;
    this.citation.vehicle = <Vehicle>{};
    this.citation.vehicleOwner = <VehicleOwner>{};
    this.citation.additionalComments = <AdditionalComments[]>[];
    this.citation.infractions = <Infraction[]>[];
    console.log('Citation just  loaded: ',this.citation);
  }


    getInfractionsChanged(infractions: Infraction[])
    {
        this.citation.infractions = infractions.filter(infraction => infraction.selected);
    }

    getCommentsChanged(comments: AdditionalComments[])
    {
        this.citation.additionalComments = comments.filter(comment => comment.comment != '');
    }


}
