
import { Component, OnInit, Input } from '@angular/core';
import { Citation } from './model/citation';
import { sequelize } from '../../database/databaseConnection';
import { citationModel } from "../../database/model/citationModel";

const electron = require('electron');
const ipcRenderer = electron.ipcRenderer;

const remote = require('electron').remote;
let window = remote.getCurrentWindow();

@Component({
    moduleId: module.id,
    selector: 'preview-citation',
    templateUrl: 'templates/preview-citation.component.html'
})
export class PreviewCitationComponent implements OnInit {

    citation = JSON.parse(localStorage.getItem("currentCitation"));

    rootDir :string = __dirname;

    printing: Boolean = false;

    constructor(){}

    ngOnInit(): void {
        console.log("CITATION", JSON.parse(localStorage.getItem("currentCitation")));
        console.log('Preview Citation Component initialized');
    }

    formatDate(date)
    {
        date = date.replace('-','/');
        date = date.replace('-','/');
        return date;
    }

    printCitation()
    {
        // this.saveCitation();
        this.printing = true;
        ipcRenderer.send('print-to-pdf', this.citation.citationNumber);
        setTimeout(() =>{
            this.printing = false;
        }, 1);
    }

    saveCitation()
    {
        let data = citationModel.build({
            name: this.citation.infractor.name,
            last_name: this.citation.infractor.lastName,
            license_number: this.citation.infractor.cardId,
            address: this.citation.infractor.address,
            tag_number: this.citation.vehicle.tagNumber,
            brand: this.citation.vehicle.brand,
            model: this.citation.vehicle.model,
            year: this.citation.vehicle.year,
            color: this.citation.vehicle.color,
            total: this.citation.infractions.length > 0 ? this.citation.infractions.reduce((sum, item) => sum + item.amount, 0) : 0
        });
        sequelize
            .authenticate()
            .then(() => {
                console.log('Connection successfully made.');
                data.save().then(() => {
                    console.log("SAVED SUCCESSFULLY");
                    window.close();
                }).catch(error => {
                    console.log("ERROR WHILE SAVING", error);
                })
            })
            .catch(err => {
                console.error('Error connecting to database', err);
            });
    }

}