"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@angular/core");
const wizard_step_component_1 = require("./wizard-step.component");
let WizardComponent = class WizardComponent {
    constructor() {
        this._steps = [];
        this._isCompleted = false;
        this.onStepChanged = new core_1.EventEmitter();
    }
    ngAfterContentInit() {
        this.wizardSteps.forEach(step => this._steps.push(step));
        this.steps[0].isActive = true;
    }
    get steps() {
        return this._steps.filter(step => !step.hidden);
    }
    get isCompleted() {
        return this._isCompleted;
    }
    get activeStep() {
        let activestep = this.steps.find(step => step.isActive);
        if (activestep == null) {
            activestep = {};
        }
        return activestep;
    }
    set activeStep(step) {
        if (step !== this.activeStep && !step.isDisabled) {
            this.activeStep.isActive = false;
            step.isActive = true;
            //this.onStepChanged.emit(step);
        }
    }
    get activeStepIndex() {
        return this.steps.indexOf(this.activeStep);
    }
    get hasNextStep() {
        return this.activeStepIndex < this.steps.length - 1;
    }
    get hasPrevStep() {
        return this.activeStepIndex > 0;
    }
    goToStep(step) {
        if (!this.isCompleted) {
            this.activeStep = step;
        }
    }
    next() {
        if (this.hasNextStep) {
            let nextStep = this.steps[this.activeStepIndex + 1];
            this.activeStep.onNext.emit();
            nextStep.isDisabled = false;
            this.activeStep = nextStep;
        }
    }
    previous() {
        if (this.hasPrevStep) {
            let prevStep = this.steps[this.activeStepIndex - 1];
            this.activeStep.onPrev.emit();
            prevStep.isDisabled = false;
            this.activeStep = prevStep;
        }
    }
    complete() {
        this.activeStep.onComplete.emit();
        this._isCompleted = true;
    }
};
tslib_1.__decorate([
    core_1.ContentChildren(wizard_step_component_1.WizardStepComponent),
    tslib_1.__metadata("design:type", core_1.QueryList)
], WizardComponent.prototype, "wizardSteps", void 0);
tslib_1.__decorate([
    core_1.Output(),
    tslib_1.__metadata("design:type", core_1.EventEmitter)
], WizardComponent.prototype, "onStepChanged", void 0);
WizardComponent = tslib_1.__decorate([
    core_1.Component({
        moduleId: module.id,
        selector: "form-wizard",
        templateUrl: "templates/wizard.component.html",
        styleUrls: ['styles/wizard.css']
    }),
    tslib_1.__metadata("design:paramtypes", [])
], WizardComponent);
exports.WizardComponent = WizardComponent;
//# sourceMappingURL=wizard.component.js.map