import {
    Component,
    Output,
    EventEmitter,
    ContentChildren,
    QueryList,
    AfterContentInit, ViewChild, ElementRef
} from "@angular/core";
import { WizardStepComponent } from "./wizard-step.component";

@Component({
  moduleId: module.id,
  selector: "form-wizard",
  templateUrl: "templates/wizard.component.html",
  styleUrls:['styles/wizard.css']
})
export class WizardComponent implements AfterContentInit {

  @ContentChildren(WizardStepComponent)
  wizardSteps: QueryList<WizardStepComponent>;

  private _steps: Array<WizardStepComponent> = [];
  private _isCompleted: boolean = false;

  @Output()
  onStepChanged: EventEmitter<WizardStepComponent> = new EventEmitter<WizardStepComponent>();

  @ViewChild('scrollContainer') private scrollContainer: ElementRef;

  constructor() {}

  ngAfterContentInit() {
    this.wizardSteps.forEach(step => this._steps.push(step));
    this.steps[0].isActive = true;
  }

  get steps(): Array<WizardStepComponent> {
    return this._steps.filter(step => !step.hidden);
  }

  get isCompleted(): boolean {
    return this._isCompleted;
  }

  get activeStep(): WizardStepComponent {
    let activestep = this.steps.find(step => step.isActive);
    if(activestep == null){
        activestep = <WizardStepComponent>{};
    }
    return activestep;
  }

  set activeStep(step: WizardStepComponent) {
    if (step !== this.activeStep && !step.isDisabled) {
      this.activeStep.isActive = false;
      step.isActive = true;
      //this.onStepChanged.emit(step);
    }
  }

  public get activeStepIndex(): number {
    return this.steps.indexOf(this.activeStep);
  }

  get hasNextStep(): boolean {
    return this.activeStepIndex < this.steps.length - 1;
  }

  get hasPrevStep(): boolean {
    return this.activeStepIndex > 0;
  }

  public goToStep(step: WizardStepComponent): void {
    if (!this.isCompleted) {
      this.activeStep = step;
    }
  }

  public setActiveStep(step: WizardStepComponent):void
  {
      for(let i = 0; i < this._steps.length; i++)
      {
          if(this._steps[i].title == step.title)
          {
              this._steps[i].isDisabled = false;
              this._steps[i].isActive = true;
              this.scrollContainer.nativeElement.scrollTop = (document.getElementById(this._steps[i].title).offsetTop - document.getElementById("cardHeader").clientHeight) - 10;
          }
          else
          {
              this._steps[i].isDisabled = true;
              this._steps[i].isActive = false;
          }
      }
  }

  public next(): void {
    if (this.hasNextStep) {
      let nextStep: WizardStepComponent = this.steps[this.activeStepIndex + 1];
      this.activeStep.onNext.emit();
      nextStep.isDisabled = false;
      this.activeStep = nextStep;
    }
  }

  public previous(): void {
    if (this.hasPrevStep) {
      let prevStep: WizardStepComponent = this.steps[this.activeStepIndex - 1];
      this.activeStep.onPrev.emit();
      prevStep.isDisabled = false;
      this.activeStep = prevStep;
    }
  }

  public complete(): void {
    this.activeStep.onComplete.emit();
    this._isCompleted = true;
  }

}
