"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const electron_1 = require("electron");
const electron_compile_1 = require("electron-compile");
const url = require("url");
const path = require("path");
// Keep a global reference of the window object, if you don't, the window will
// be closed automatically when the JavaScript object is garbage collected.
let mainWindow;
let additionalWindow;
let mainMenuTemplate;
const isProductionModeOn = !process.execPath.match(/[\\/]electron/);
if (!isProductionModeOn)
    electron_compile_1.enableLiveReload();
const createWindow = () => tslib_1.__awaiter(this, void 0, void 0, function* () {
    // Create the browser window.
    mainWindow = new electron_1.BrowserWindow();
    // and load the index.html of the app.
    mainWindow.loadURL(url.format({
        pathname: path.join(__dirname, "index.html"),
        protocol: "file",
        slashes: true
    }));
    // Emitted when the window is closed.
    mainWindow.on("closed", () => {
        mainWindow = null;
        electron_1.app.quit();
    });
    mainMenuTemplate = createApplicationMenu();
    handleMenuOnMac();
    handlegDebugMenu();
    //add the menu
    const mainMenu = electron_1.Menu.buildFromTemplate(mainMenuTemplate);
    //Inset the menu
    electron_1.Menu.setApplicationMenu(mainMenu);
});
// This method will be called when Electron has finished
// initialization and is ready to create browser windows.
// Some APIs can only be used after this event occurs.
electron_1.app.on("ready", createWindow);
// Quit when all windows are closed.
electron_1.app.on("window-all-closed", () => {
    // On OS X it is common for applications and their menu bar
    // to stay active until the user quits explicitly with Cmd + Q
    if (process.platform !== "darwin") {
        electron_1.app.quit();
    }
});
electron_1.app.on("activate", () => {
    // On OS X it's common to re-create a window in the app when the
    // dock icon is clicked and there are no other windows open.
    if (mainWindow === null) {
        createWindow();
    }
});
//Create menu template
function createApplicationMenu() {
    return [
        {
            label: "Mobile Citation",
            submenu: [
                {
                    label: "Create a Citation",
                    click() {
                        console.log("Here most show the citation wizard");
                        runAWindows("wizard", "Citation Wizard");
                    }
                },
                {
                    label: "Create a Crash Report",
                    click() {
                        console.log("Here should appear a crash report wizard");
                    }
                },
                {
                    role: "reload"
                },
                {
                    label: "Quit",
                    accelerator: process.platform.toString() == "darwin" ? "Command+Q" : "Ctrl+Q",
                    click() {
                        electron_1.app.quit();
                    }
                }
            ]
        }
    ];
}
// In this file you can include the rest of your app's specific main process
// code. You can also put them in separate files and import them here.
function runAWindows(navigateTo, windowTitle) {
    additionalWindow = new electron_1.BrowserWindow({
        width: 800,
        height: 600,
        title: windowTitle
    });
    const navigation = url.format({
        pathname: path.join(__dirname, "index.html"),
        protocol: "file",
        slashes: true,
        hash: navigateTo
    });
    additionalWindow.loadURL(navigation);
    //additionalWindow.webContents.toggleDevTools();
}
function handleMenuOnMac() {
    console.log(process.platform.toString());
    if (process.platform.toString() == "darwin") {
        const emptyMenu = {};
        mainMenuTemplate.unshift(emptyMenu);
    }
}
function handlegDebugMenu() {
    //if (!isProductionModeOn) {
    mainMenuTemplate.push({
        label: "Developer Tools",
        submenu: [
            {
                label: "Open Dev Console",
                accelerator: process.platform.toString() == "darwin" ? "Command+I" : "Ctrl+I",
                click(item, focusedWindow) {
                    console.log(item);
                    focusedWindow.webContents.toggleDevTools();
                }
            },
            {
                role: "reload"
            }
        ]
    });
    // }
}
//# sourceMappingURL=index.js.map